function chunk_id = make_chunks(probe_id, probe_chr, intergenic_blocks, chunk_size)

% chunk_id = make_chunks(probe_id, probe_chr, intergenic_blocks, chunk_size)
%
% Partitions the chromosomal data into chunks, each approximately of
% chunk_size, cutting in intergenic regions only.
%
% probe_id -- genomic locations (chr*10^8+position) of each probe (length N)
% probe_chr -- the chromosome of each probe's location (length N)
% intergenic_blocks -- intergenic regions given as a k x 2 matrix (first
%   column indicates region start, second one region end)
% chunk_size -- the desired length of chunks
% returns a vector of N natural numbers indicating the partition
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

b_idx = 1;
chunk_id = zeros(size(probe_id));
chunk_cnt = 1; 
chr = 1;
while chr<=5,
  % find next intergenic region to place chunk end
  e = probe_id(b_idx)+chunk_size;
  while 1,
    ige_bl = min(find(probe_id(intergenic_blocks(1,:))>e));
    if isempty(ige_bl) ...
          || floor(probe_id(intergenic_blocks(1,ige_bl))/100000000) > chr,
      e_idx = max(find(probe_chr==chr));
      chr = chr + 1;
      break
    end
    
    ige_len = intergenic_blocks(2,ige_bl)-intergenic_blocks(1,ige_bl)+1;
    if ige_len>=100, % split only in regions of at least 100 probes
      e_idx = floor((intergenic_blocks(1,ige_bl) ... 
                    + intergenic_blocks(2,ige_bl))/2);
      break
    end
    e = probe_id(intergenic_blocks(2,ige_bl)) + 1;
  end
  assert(all(chunk_id(b_idx:e_idx)==0));
  chunk_id(b_idx:e_idx) = chunk_cnt;
  
  chunk_cnt = chunk_cnt + 1;
  b_idx = e_idx + 1;
  
  fprintf('chr %i, chunk %i\r', chr, chunk_cnt);
end
assert(~any(chunk_id==0));

% eof