function [acc, thresh] = opt_threshold(intensity, label, threshold)

% [acc thresh] = opt_threshold(intensity, label, [threshold])
%
% Determines the optimal threshold for separating exonic from
% intronic/intergenic probe intensities as well as the corresponding
% separation accuracy.
%
% intensity -- a vector of probe intensities of lengh N
% label -- a vector of probe annotations (length N)
%   see get_label_set_mSTAD.m
% threshold -- optional parameter to predefine the threshold value; if
%   given no threshold is optimized, and only separation accuracy is
%   computed
% returns the accuracy (defined as the sum of true positive and true
%   negative exon probes) for the best threshold as well as the threshold
%   value itself
%
% written by Gunnar Raetsch & Georg Zeller, MPI Tuebingen, Germany, 2007-2008

LABELS = get_label_set_mSTAD();

if exist('threshold', 'var'),
  s = threshold; 
else
  s = sort(intensity);
  s = [s s(end)+1];
end

i = 0;
for t=s-1e-6,
  i = i + 1;
  acc(i) = sum(label(intensity>t)==LABELS.exonic) ...
          + sum(label(intensity<t)~=LABELS.exonic);
end

[max_acc, idx] = max(acc);
thresh = s(idx);
acc = max_acc/length(label);

% eof