function fh = print_evaluation(eval, fid);

% fh = print_evaluation(eval, fid);
%
% Prints a summary of segmentation evaluation.
%
% eval -- a struct with fields containing performace estimates
% fid -- on optional file descriptor to which output is written (stdin is
%   used for output instead if fid is not specified)
% returns a handle to the evaluation figure
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

display_all = 1;

if ~exist('fid', 'var'),
  fid = 1;
end

probe_ACC        = [eval.probe_ACC];
probe_SN         = [eval.probe_SN];
probe_SP         = [eval.probe_SP];
exon_SN          = [eval.exon_SN];
exon_SP          = [eval.exon_SP];
exon_FN          = [eval.exon_FN];
exon_FP          = [eval.exon_FP];
exon_boundary_SN = [eval.exon_boundary_SN];
exon_boundary_SP = [eval.exon_boundary_SP];


fprintf(['\n%s\n\n' ...
         '  probe-level accuracy:       %2.2f%%\n'...
         '  probe-level sensitivity:    %2.2f%%\n' ...
         '  probe-level specificity:    %2.2f%%\n\n', ...
         '  exon-level sensitivity:     %2.2f%%\n', ...
         '  exon-level specificity:     %2.2f%%\n\n', ...
         '  exon-overlap sensitivity:   %2.2f%%\n', ...
         '  exon-overlap specificity:   %2.2f%%\n\n', ...
         '  exon-boundary sensitivity:  %2.2f%%\n', ...
         '  exon-boundary specificity:  %2.2f%%\n\n'], ...
        eval(1).method, ...
        100*mean(probe_ACC(~isnan(probe_ACC))), ...
        100*mean(probe_SN(~isnan(probe_SN))), ...
        100*mean(probe_SP(~isnan(probe_SP))), ...
        100*mean(exon_SN(~isnan(exon_SN))), ...
        100*mean(exon_SP(~isnan(exon_SP))), ...
        100*mean(1 - exon_FN(~isnan(exon_FN))), ...
        100*mean(1 - exon_FP(~isnan(exon_FP))), ...
        100*mean(exon_boundary_SN(~isnan(exon_boundary_SN))), ...
        100*mean(exon_boundary_SP(~isnan(exon_boundary_SP))));

if isfield(eval, 'expr_level'),
  levels = unique([eval.expr_level]);
  levels = levels(~isnan(levels));
  bars_1 = [];
  bars_2 = [];
  for i=1:length(levels),
    lvl_idx = [eval.expr_level]==levels(i);
    
    bars_1(1,i) = 100*mean(probe_SN(lvl_idx & ~isnan(probe_SN)));
    bars_1(2,i) = 100*mean(exon_SN(lvl_idx & ~isnan(exon_SN)));
    bars_1(3,i) = 100*mean(exon_boundary_SN(lvl_idx & ~isnan(exon_boundary_SN)));
    bars_1(4,i) = 100*mean(1 - exon_FN(lvl_idx & ~isnan(exon_FN)));
  
    bars_2(1,i) = 100*mean(probe_SP(lvl_idx & ~isnan(probe_SP)));
    bars_2(2,i) = 100*mean(exon_SP(lvl_idx & ~isnan(exon_SP)));
    bars_2(3,i) = 100*mean(exon_boundary_SP(lvl_idx & ~isnan(exon_boundary_SP)));
    bars_2(4,i) = 100*mean(1 - exon_FP(lvl_idx & ~isnan(exon_FP)));
  end
  
  fh = figure;
  sph = subplot(3,1,1);
  if display_all,
    bar(bars_1, 'grouped');
    axis([0.5 size(bars_1,1)+0.5 0 105]);
    x_tick_labels = {'probe SN', 'exon SN', 'exon boundary SN', ...
                     'exon overlap SN', 'mean length FN exons'};
  else
    bar(bars_1([1,4],:), 'grouped');
    axis([0.5 2.5 0 105]);
    x_tick_labels = {'probe SN', 'exon overlap SN'};
  end
  ylabel('percent');
  set(sph, 'XTickLabel', x_tick_labels);
  grid on
 
  sph = subplot(3,1,2);
  if display_all,
    bar(bars_2, 'grouped');
    axis([0.5 size(bars_2,1)+0.5 0 105]);
    x_tick_labels = {'probe SP', 'exon SP', 'exon boundary SP', ...
                     'exon overlap SP', 'mean length FP exons'};
  else
    bar(bars_2([1,4],:), 'grouped');
    axis([0.5 2.5 0 105]);
    x_tick_labels = {'probe SP', 'exon overlap SP'};
  end
  ylabel('percent');
  set(sph, 'XTickLabel', x_tick_labels);
  grid on
  
  sph = subplot(3,1,3);
  n = hist([eval.expr_level], 1:10);
  bar(1:10, n, 'BarWidth', 1);
  xlabel('discrete expression level');
  ylabel('number of examples');
else
  fh = [];
end

% eof