function bins = discretize_expression(intensity, label, exm_id, L)

% bins = discretize_expression(intensity, label, exm_id, L)
%
% Computes bin boundaries for L discrete levels of exonic intensity such
% that each bin contains approximately equally many genes.
%
% intensity -- a vector of hybridization intensity (of length N)
% label -- a labeling of probes (of length N) used to determine exonic
%   probes
% exm_id -- a vector of N example IDs (pos. integers) indicating to
%   which example a label belongs to (e.g. 11111222 means that the first
%   example is a sequence of length 5 and is followed by the second
%   example sequence of length 3)
% L -- the desired number oc discrete expression levels
% returns L bin boundaries (as a vector of size L x 2)
%
% see get_label_set_mSTAD.m
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

LABELS = get_label_set_mSTAD();

fprintf('Computing discrete expression levels across genes...\n');

exon_idx = find(label==LABELS.exonic);
exon_intensity = intensity(exon_idx);
exm_id = exm_id(exon_idx);

unq_exm = unique(exm_id);
median_exo_I = nan(size(unq_exm));

tic
for i=1:length(unq_exm),
  idx = find(exm_id==unq_exm(i));
  median_exo_I(i) = median(exon_intensity(idx));
  if mod(i,100) == 0,
    fprintf('  %2.1f%% (%.1f sec)\r', 100*i/length(unq_exm), toc);
  end
end
fprintf('  %2.1f%% (%.1f sec)\n', 100*i/length(unq_exm), toc);

x = sort(median_exo_I);
x = x(~isnan(x));
bins = x(round(linspace(1, length(x), L+1)));
bins = [[-inf; bins(2:end-1)'], [bins(2:end-1)'; inf]];

%for i=1:L,
%  disp(sum(bins(i,1) <= median_exo_I & median_exon_I < bins(i,2)));
%end

% eof