function [state_model, A, a_trans] = make_model_mSTAD(PAR, transition_scores)

% [state_model, A, a_trans] = make_model_mSTAD(PAR, [transition_scores])
%
% Combines user specification and automatic completion of the
% state-transition model.
% 
% PAR -- a struct of parameters specified in setup_training.m and
%   train_hmsvm.m
% transition_scores -- optional parameter; if specified, transition scores
%   of A and a_trans will be set accordingly (otherwise initialized to 0)
% returns the fully specified graphical model (state_model), the transition
%   matrix (A) and its sparse representation used for Viterbi decoding in
%   Shogun (a_trans)
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

state_model = specify_model(PAR);

if exist('transition_scores', 'var'),
  [state_model, A, a_trans] = complete_model(state_model, PAR, ...
                                             transition_scores);
else
  [state_model, A, a_trans] = complete_model(state_model, PAR);
end

% eof