function level = states_to_levels(state_seq, PAR)

% level = states_to_levels(state_seq, PAR)
%
% Parses the predicted expression level from a state sequence. Non-exonic
% states will have level 0.
%
% state_seq -- sequence of states of lenth n
% PAR -- a struct of parameters specified in setup_training.m and
%   train_hmsvm.m
% returns a sequence of predicted expression levels of length n (which is
%   0 for al probes not predicted to be exonic, and between 1 and
%   PAR.num_levels else)
%
% written by Georg Zeller, MPI Tuebingen, Germany 2007-2008

% get label set and state names
LABELS = get_label_set_mSTAD();
STATES = get_state_set_mSTAD(PAR);

% get state ids of exon states (soreted by level)
fn = fieldnames(STATES);
exo_f_idx = strmatch('exo_f_', fn);
assert(length(exo_f_idx) == PAR.num_levels);
exo_s_idx = strmatch('exo_s_', fn);
assert(length(exo_s_idx) == PAR.num_levels);

% convert state sequence into level sequence
level = zeros(size(state_seq)); % nonexonic states will have level 0
for i=1:PAR.num_levels,
  idx = find(state_seq == exo_f_idx(i) | state_seq == exo_s_idx(i));
  level(idx) = i;
end

% eof