% Main script for applying trained mSTAD instances to whole genome prediction 
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

% adjust set_mSTAD_paths.m to point to the correct directories
addpath ../
set_mSTAD_paths();
set_hmsvm_paths();

% single letter identifier of the experimental series
series = 'T'
% array numbers (e.g use 1:6 if series comprises 6 arrays)
array_idx = 3:3;
% number of training iterations for the mSTAD model (leave empty to use
% the mSTAD instance after convergence)
iteration = [];

% filename suffix denoting the type of normalization applied to the array
% data (RR indicates transcript normalized intensities obtained by Ridge Regression)
I_type = 'RR';
% directory from which the mSTAD input data are loaded
data_dir = ['../../../PSB_data/mSTAD/input_data'];
% array file name suffix (indicating how array data has been preprocessed)
array_suffix = sprintf('ABC_R_A_QN_%s', I_type)
% number of predictors used to obtain whole-genome predictions
% this number should be > 1 to avoid prediction on sequences which have
% been used to train mSTAD
num_predictors = 2;
% directories from which the mSTAD predictors are loaded
predictor_dirs = {'mSTAD_result_2008-09-18_17h37_model1/', ...
                  'mSTAD_result_2008-09-18_17h37_model2/', ...
                 };
assert(length(predictor_dirs) == num_predictors);

% specify which trained mSTAD instances should be used for prediction
for i=1:length(array_idx);
  dir_idx{i} = [1, 2]; % mSTAD instances 1 and 2 are used to predict all arrays
end

for i=1:length(array_idx),
  assert(length(dir_idx{i}) == num_predictors);
end
assert(length(dir_idx) == length(array_idx));

% if data need to be prepared for segmentation, do so
for i=array_idx,
  if ~fexist(sprintf('%s/%s_%03i_%s_segm.mat', data_dir, series, i, array_suffix)),
    prepare_data(sprintf('%s_%03i', series, i), I_type, 'ABC');
  end
end

% perform whole-genome prediction
for i=1:length(array_idx),
  array_id = sprintf('%s_%03i_%s', series, array_idx(i), array_suffix);
  predict_genome(predictor_dirs(dir_idx{i}), array_id, iteration);  
end

% eof