function [chunk_subsets exm_subsets] = partition_data(chunk_id, exm_id, N)

% [chunk_subsets exm_subsets] = partition_data(chunk_id, exm_id, N)
%
% Randomly subdivides data into  N subsets. Data chunks are distributed
% such that each subset contains approximately equally many. Useful for
% crossvalidation.
%
% chunk_id -- a vector of chunk IDs (pos. integers) indicating to which
%   chunk a data point belongs (e.g. 11111222 means that the first chunk
%   has length 5 and is followed by the second chunk of length 3).Data
%   splits occur at chunk boundaries, i.e. chunks remain intact. 
% exm_id -- a vector of n example IDs (pos. integers) indicating to
%   which example sequence a data point belongs
% N -- desired number of subsets
% returns the example ids of the subset of sequences compatible with the
%   assumpations made for mSTAD training 
%
% see setup_training.m prepare_data.m
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

unq_cid = unique(chunk_id);
unq_cid = unq_cid(randperm(length(unq_cid)));
subset_ends = round(linspace(0,length(unq_cid), N+1));
for i=1:N
  chunk_subsets{i} = sort(unq_cid(subset_ends(i)+1:subset_ends(i+1)));
  exm_subsets{i} = unique(exm_id(ismember(chunk_id, chunk_subsets{i})));
end
assert(isequal(sort([chunk_subsets{:}]), sort(unq_cid)));

% eof