function [RRs JOB_INFO] = model_sel_Ridge(RR, OPT, JOB_INFO);

% [RRs JOB_INFO] = model_sel_Ridge(RR, OPT, JOB_INFO);
%
% Performs model selection for Ridge regression submitting parallel
% cluster jobs if OPT.USE_RPROC==1.
%
% RR -- a generic regressor struct which has fields specifying training
%   data and labels
% OPT -- a struct of settings (see main_training)
% JOB_INFO -- a job info struct for rpoc, can be empty but has to exist
%   if OPT.USE_RPROC==1
% returns a struct array containing Ridge regressor objects and a
%   JOB_INFO object if OPT.USE_RPROC==1
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

% constant parameter
RR.PARAM.order = OPT.RR.PARAM.order;

% grid search for model selection
for i=1:length(OPT.RR.MOD_SEL_PARAM.lambda),
  RR.PARAM.lambda = OPT.RR.MOD_SEL_PARAM.lambda(i);
  RR.PARAM.fn_out = sprintf('%strained_rr_fold%i_quant%i_lambda%1.5f_o%i.mat', ...
                            RR.PARAM.out_dir, RR.fold_id, RR.quant_id, RR.PARAM.lambda, ...
                            RR.PARAM.order);
  
  RRs(RR.quant_id) = RR;
  
  fprintf('Training Ridge regressor for %ith quantile, intensity range [%2.3f, %2.3f]...\n', ...
          RR.quant_id, RR.I_min, RR.I_max);

  if OPT.USE_RPROC,
    assert(exist('JOB_INFO')==1);
    
    % RPROC settings
    RPROC_MEMREQ             = 2700;
    RPROC_OPT.express        = 0;
    RPROC_OPT.immediately_bg = 0;
    RPROC_OPT.immediately    = 0;
    RPROC_OPT.arch           = 64; % take only 64 bit nodes
    RPROC_OPT.identifier     = sprintf('TAtrRRp%i_lambda%3.3f_o%i_', ...
                                       RR.quant_id, RR.PARAM.lambda, ...
                                       RR.PARAM.order);
    RPROC_TIME               = 5*60; % mins
    
    JOB_INFO{end+1} = rproc('train_Ridge', ...
                            RR, RPROC_MEMREQ, RPROC_OPT, RPROC_TIME);
    fprintf('\nSubmitted job %i\n\n', length(JOB_INFO));
  else
    train_Ridge(RR);
  end
end
