function RR = train_Ridge(RR);

% RR = train_Ridge(RR);
%
% Does the actual Ridge regression training.
%
% RR -- a regressor struct which has fields specifying training data,
%   labels and hyperparameter values
% returns a Ridge regressor struct augmented by the weight vector w 
%   as well as training errors 
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

% generate numerical kmer vectors from sequences
tic
RR.X_train_num = seq_2_kmers(RR.X_train_1, RR.PARAM.order);
RR.X_train_num = [RR.X_train_num; RR.X_train_2];
fprintf('feature generation took %.1fs.\n', toc);

RR = rmfield(RR, 'X_train_1');
RR = rmfield(RR, 'X_train_2');

if RR.DIST_CORRECTION,
  RR.X_train_num = [RR.X_train_num; RR.X_train_3];
  RR = rmfield(RR, 'X_train_3');
end

disp(RR);
disp(RR.PARAM);

tic
% regularizer
x_dim = size(RR.X_train_num, 1);
R = RR.PARAM.lambda * eye(x_dim, x_dim);
% number of training examples
N = size(RR.X_train_num,2);
Q = RR.X_train_num * RR.X_train_num';
b = RR.X_train_num * RR.Y_train';
RR.w = (R + Q)\b;
assert(~any(isnan(RR.w)));
fprintf('Training took %.1fs.\n', toc);

% training error
Y_pred = nan(1,N);
for i=1:N,
  Y_pred(i) = RR.w' * RR.X_train_num(:,i);
end

RR.Q1_TR = mean(abs(Y_pred - RR.Y_train)) ...
    / mean(abs(RR.Y_train - median(RR.Y_train)));
RR.Q2_TR = mean((Y_pred - RR.Y_train).^2) ...
    / mean((RR.Y_train - mean(RR.Y_train)).^2);

RR = rmfield(RR, 'X_train_num');
RR = rmfield(RR, 'Y_train');

disp(RR);
save(RR.PARAM.fn_out, 'RR');

