function write_normalized_I(intensities, I_probe_ids, fn_out, target_probe_ids)
  
% write_normalized_I(intensities, I_probe_ids, fn_out, target_probe_ids)
%
% Writes hybridization intensities to a flat file.
%
% intensities -- a struct whose intensity fields (various raw and
%   normalized intensity vectors) are written
% I_probe_ids -- genomic locations of tiling probes
% fn_out -- the filename of the output file
% target_probe_ids -- option to specify a subset of probe ids for which
%   intensties are written
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

[tmp idx_i idx_t] = intersect(I_probe_ids, target_probe_ids);

I_norm = -ones(length(target_probe_ids), length(fieldnames(intensities)));
assert(all(size(intensities.PM_I) == size(I_probe_ids)));
I_norm(idx_t, 1) = intensities.PM_I(idx_i);
fn_out = [fn_out '_RAW'];

col = 2;
if isfield(intensities, 'PM_I_n_SQN'),
  assert(all(size(intensities.PM_I_n_SQN) == size(I_probe_ids)));
  I_norm(idx_t, col) = intensities.PM_I_n_SQN(idx_i);
  col = col+1;
  fn_out = [fn_out '_SQN'];
end
if isfield(intensities, 'PM_I_n_SVR'),
  assert(all(size(intensities.PM_I_n_SVR) == size(I_probe_ids)));
  I_norm(idx_t, col) = intensities.PM_I_n_SVR(idx_i);
  col = col+1;
  fn_out = [fn_out '_SVM'];
end
if isfield(intensities, 'PM_I_n_RR'),
  assert(all(size(intensities.PM_I_n_RR) == size(I_probe_ids)));
  I_norm(idx_t, col) = intensities.PM_I_n_RR(idx_i);
  col = col+1;
  fn_out = [fn_out '_RR'];
end
fn_out = [fn_out '.txt'];

[fid msg] = fopen(fn_out, 'w');
disp(msg);

for i=1:length(target_probe_ids),
  switch size(I_norm,2),
   case 1,
    fprintf(fid, '%i\t%.3f\n', ...
            target_probe_ids(i), I_norm(i,1));
   case 2,
    fprintf(fid, '%i\t%.3f\t%.3f\n', ...
            target_probe_ids(i), I_norm(i,1), I_norm(i,1));    
   case 3,
    fprintf(fid, '%i\t%.3f\t%.3f\t%.3f\n', ...
            target_probe_ids(i), I_norm(i,1), I_norm(i,2), I_norm(i,3));    
   case 4,
    fprintf(fid, '%i\t%.3f\t%.3f\t%.3f\t%.3f\n', ...
            target_probe_ids(i), I_norm(i,1), I_norm(i,2), I_norm(i,3), I_norm(i,4));    
  end
end
fclose(fid);
